@@ -22,10 +22,7 @@ test_that("Can access the sass behind all versions and Bootswatch themes", {
 # changes, we should check to make sure we've made the appropriate changes in bootstrap_bundle()
 # (and once we have, then this hash should be updated as well).
 test_that("Make sure bootstrap.scss hasn't changed", {
-  skip_on_cran()
-
-  scss <- lib_file("bs", "scss", "bootstrap.scss")
-  hash_new <- digest::digest(readLines(scss))
-  hash_old <- testthat::test_path("test-assets", "bootstrap_scss_hash.txt")
-  expect_equal(hash_new, readLines(hash_old))
+  expect_snapshot_file(
+    lib_file("bs", "scss", "bootstrap.scss")
+  )
 })
